Struct google_sql1_beta4::api::AclEntry [−][src]
pub struct AclEntry {
pub expiration_time: Option<String>,
pub kind: Option<String>,
pub name: Option<String>,
pub value: Option<String>,
}Expand description
An entry for an Access Control list.
This type is not used in any activity, and only used as part of another schema.
Fields
expiration_time: Option<String>The time when this access control entry expires in RFC 3339 format, for example
2012-11-15T16:19:00.094Z.
kind: Option<String>This is always sql#aclEntry.
name: Option<String>Optional. A label to identify this entry.
value: Option<String>The whitelisted value for the access control list.