Struct google_sql1_beta4::api::BackupConfiguration [−][src]
pub struct BackupConfiguration {
pub binary_log_enabled: Option<bool>,
pub enabled: Option<bool>,
pub kind: Option<String>,
pub location: Option<String>,
pub point_in_time_recovery_enabled: Option<bool>,
pub replication_log_archiving_enabled: Option<bool>,
pub start_time: Option<String>,
}Expand description
Database instance backup configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
binary_log_enabled: Option<bool>(MySQL only) Whether binary log is enabled. If backup configuration is disabled, binarylog must be disabled as well.
enabled: Option<bool>Whether this configuration is enabled.
kind: Option<String>This is always sql#backupConfiguration.
location: Option<String>Location of the backup
point_in_time_recovery_enabled: Option<bool>Reserved for future use.
replication_log_archiving_enabled: Option<bool>Reserved for future use.
start_time: Option<String>Start time for the daily backup configuration in UTC timezone in the 24
hour format - HH:MM.