Struct google_sql1_beta4::api::BackupRunMethods [−][src]
pub struct BackupRunMethods<'a> { /* fields omitted */ }Expand description
A builder providing access to all methods supported on backupRun resources.
It is not used directly, but through the SQLAdmin hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_sql1_beta4 as sql1_beta4;
use std::default::Default;
use oauth2;
use sql1_beta4::SQLAdmin;
let secret: oauth2::ApplicationSecret = Default::default();
let auth = yup_oauth2::InstalledFlowAuthenticator::builder(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = SQLAdmin::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `insert(...)` and `list(...)`
// to build up your call.
let rb = hub.backup_runs();Implementations
Create a builder to help you perform the following task:
Deletes the backup taken by a backup run.
Arguments
project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.id- The ID of the Backup Run to delete. To find a Backup Run ID, use the list method.
Create a builder to help you perform the following task:
Retrieves a resource containing information about a backup run.
Arguments
project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.id- The ID of this Backup Run.
Create a builder to help you perform the following task:
Creates a new backup run on demand. This method is applicable only to Second Generation instances.
Arguments
request- No description provided.project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.
Create a builder to help you perform the following task:
Lists all backup runs associated with a given instance and configuration in the reverse chronological order of the backup initiation time.
Arguments
project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.