Struct google_sql1_beta4::api::BackupRunsListResponse [−][src]
pub struct BackupRunsListResponse {
pub items: Option<Vec<BackupRun>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
Backup run list results.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list backup runs (response)
Fields
items: Option<Vec<BackupRun>>A list of backup runs in reverse chronological order of the enqueued time.
kind: Option<String>This is always sql#backupRunsList.
next_page_token: Option<String>The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results.