Struct google_sql1_beta4::api::BinLogCoordinates [−][src]
pub struct BinLogCoordinates {
pub bin_log_file_name: Option<String>,
pub bin_log_position: Option<String>,
pub kind: Option<String>,
}Expand description
Binary log coordinates.
This type is not used in any activity, and only used as part of another schema.
Fields
bin_log_file_name: Option<String>Name of the binary log file for a Cloud SQL instance.
bin_log_position: Option<String>Position (offset) within the binary log file.
kind: Option<String>This is always sql#binLogCoordinates.