Struct google_sql1_beta4::api::CloneContext [−][src]
pub struct CloneContext {
pub bin_log_coordinates: Option<BinLogCoordinates>,
pub destination_instance_name: Option<String>,
pub kind: Option<String>,
pub pitr_timestamp_ms: Option<String>,
pub point_in_time: Option<String>,
}Expand description
Database instance clone context.
This type is not used in any activity, and only used as part of another schema.
Fields
bin_log_coordinates: Option<BinLogCoordinates>Binary log coordinates, if specified, identify the position up to which the source instance should be cloned. If not specified, the source instance is cloned up to the most recent binary log coordinates.
destination_instance_name: Option<String>Name of the Cloud SQL instance to be created as a clone.
kind: Option<String>This is always sql#cloneContext.
pitr_timestamp_ms: Option<String>Reserved for future use.
point_in_time: Option<String>Reserved for future use.