Struct google_sql1_beta4::api::DatabaseFlags [−][src]
Database flags for Cloud SQL instances.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>The name of the flag. These flags are passed at instance startup, so include both server options and system variables for MySQL. Flags should be specified with underscores, not hyphens. For more information, see Configuring Database Flags in the Cloud SQL documentation.
value: Option<String>The value of the flag. Booleans should be set to on for true
and off for false. This field must be omitted if the flag
doesn’t take a value.