Struct google_sql1_beta4::api::DatabaseInstanceFailoverReplica [−][src]
pub struct DatabaseInstanceFailoverReplica {
pub available: Option<bool>,
pub name: Option<String>,
}Expand description
The name and status of the failover replica. This property is applicable only to Second Generation instances.
This type is not used in any activity, and only used as part of another schema.
Fields
available: Option<bool>The availability status of the failover replica. A false status indicates that the failover replica is out of sync. The master can only failover to the failover replica when the status is true.
name: Option<String>The name of the failover replica. If specified at instance creation, a failover replica is created for the instance. The name doesn’t include the project ID. This property is applicable only to Second Generation instances.