Struct google_sql1_beta4::api::DatabaseMethods [−][src]
pub struct DatabaseMethods<'a> { /* fields omitted */ }Expand description
A builder providing access to all methods supported on database resources.
It is not used directly, but through the SQLAdmin hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_sql1_beta4 as sql1_beta4;
use std::default::Default;
use oauth2;
use sql1_beta4::SQLAdmin;
let secret: oauth2::ApplicationSecret = Default::default();
let auth = yup_oauth2::InstalledFlowAuthenticator::builder(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = SQLAdmin::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `insert(...)`, `list(...)`, `patch(...)` and `update(...)`
// to build up your call.
let rb = hub.databases();Implementations
Create a builder to help you perform the following task:
Deletes a database from a Cloud SQL instance.
Arguments
project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.database- Name of the database to be deleted in the instance.
Create a builder to help you perform the following task:
Retrieves a resource containing information about a database inside a Cloud SQL instance.
Arguments
project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.database- Name of the database in the instance.
Create a builder to help you perform the following task:
Inserts a resource containing information about a database inside a Cloud SQL instance.
Arguments
request- No description provided.project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.
Create a builder to help you perform the following task:
Lists databases in the specified Cloud SQL instance.
Arguments
project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.
Create a builder to help you perform the following task:
Partially updates a resource containing information about a database inside a Cloud SQL instance. This method supports patch semantics.
Arguments
request- No description provided.project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.database- Name of the database to be updated in the instance.
Create a builder to help you perform the following task:
Updates a resource containing information about a database inside a Cloud SQL instance.
Arguments
request- No description provided.project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.database- Name of the database to be updated in the instance.