Struct google_sql1_beta4::api::DemoteMasterConfiguration [−][src]
pub struct DemoteMasterConfiguration {
pub kind: Option<String>,
pub mysql_replica_configuration: Option<DemoteMasterMySqlReplicaConfiguration>,
}Expand description
Read-replica configuration for connecting to the on-premises master.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>This is always sql#demoteMasterConfiguration.
mysql_replica_configuration: Option<DemoteMasterMySqlReplicaConfiguration>MySQL specific configuration when replicating from a MySQL on-premises
master. Replication configuration information such as the username,
password, certificates, and keys are not stored in the instance metadata.
The configuration information is used only to set up the replication
connection and is stored by MySQL in a file named master.info
in the data directory.