Struct google_sql1_beta4::api::DemoteMasterContext [−][src]
pub struct DemoteMasterContext {
pub kind: Option<String>,
pub master_instance_name: Option<String>,
pub replica_configuration: Option<DemoteMasterConfiguration>,
pub verify_gtid_consistency: Option<bool>,
}Expand description
Database instance demote master context.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>This is always sql#demoteMasterContext.
master_instance_name: Option<String>The name of the instance which will act as on-premises master in the replication setup.
replica_configuration: Option<DemoteMasterConfiguration>Configuration specific to read-replicas replicating from the on-premises master.
verify_gtid_consistency: Option<bool>Verify GTID consistency for demote operation. Default value:
True. Second Generation instances only. Setting this flag to
false enables you to bypass GTID consistency check between on-premises
master and Cloud SQL instance during the demotion operation but also
exposes you to the risk of future replication failures. Change the value
only if you know the reason for the GTID divergence and are confident that
doing so will not cause any replication issues.