Struct google_sql1_beta4::api::DemoteMasterMySqlReplicaConfiguration [−][src]
pub struct DemoteMasterMySqlReplicaConfiguration {
pub ca_certificate: Option<String>,
pub client_certificate: Option<String>,
pub client_key: Option<String>,
pub kind: Option<String>,
pub password: Option<String>,
pub username: Option<String>,
}Expand description
Read-replica configuration specific to MySQL databases.
This type is not used in any activity, and only used as part of another schema.
Fields
ca_certificate: Option<String>PEM representation of the trusted CA’s x509 certificate.
client_certificate: Option<String>PEM representation of the slave’s x509 certificate.
client_key: Option<String>PEM representation of the slave’s private key. The corresponsing public key is encoded in the client’s certificate. The format of the slave’s private key can be either PKCS #1 or PKCS #8.
kind: Option<String>This is always sql#demoteMasterMysqlReplicaConfiguration.
password: Option<String>The password for the replication connection.
username: Option<String>The username for the replication connection.