Struct google_sql1_beta4::api::DiskEncryptionStatus [−][src]
pub struct DiskEncryptionStatus {
pub kind: Option<String>,
pub kms_key_version_name: Option<String>,
}Expand description
Disk encryption status for an instance.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>This is always sql#diskEncryptionStatus.
kms_key_version_name: Option<String>KMS key version used to encrypt the Cloud SQL instance resource