Struct google_sql1_beta4::api::ExportContext [−][src]
pub struct ExportContext {
pub csv_export_options: Option<ExportContextCsvExportOptions>,
pub databases: Option<Vec<String>>,
pub file_type: Option<String>,
pub kind: Option<String>,
pub sql_export_options: Option<ExportContextSqlExportOptions>,
pub uri: Option<String>,
}Expand description
Database instance export context.
This type is not used in any activity, and only used as part of another schema.
Fields
csv_export_options: Option<ExportContextCsvExportOptions>Options for exporting data as CSV.
databases: Option<Vec<String>>Databases to be exported.
MySQL instances: If
fileType is SQL and no database is specified, all
databases are exported, except for the mysql system database.
If fileType is CSV, you can specify one database,
either by using this property or by using the
csvExportOptions.selectQuery property, which takes precedence
over this property.
PostgreSQL instances: You must specify
one database to be exported. If fileType is CSV,
this database must match the one specified in the
csvExportOptions.selectQuery property.
file_type: Option<String>The file type for the specified uri. SQL: The file
contains SQL statements. CSV: The file contains CSV data.
kind: Option<String>This is always sql#exportContext.
sql_export_options: Option<ExportContextSqlExportOptions>Options for exporting data as SQL statements.
uri: Option<String>The path to the file in Google Cloud Storage where the export will be
stored. The URI is in the form gs:
//bucketName/fileName. If the file already exists, the requests
// succeeds, but the operation fails. If fileType is
// SQL and the filename ends with .gz, the contents are
// compressed.