Struct google_sql1_beta4::api::ExportContextSqlExportOptions [−][src]
pub struct ExportContextSqlExportOptions {
pub mysql_export_options: Option<ExportContextSqlExportOptionsMysqlExportOptions>,
pub schema_only: Option<bool>,
pub tables: Option<Vec<String>>,
}Expand description
Options for exporting data as SQL statements.
This type is not used in any activity, and only used as part of another schema.
Fields
mysql_export_options: Option<ExportContextSqlExportOptionsMysqlExportOptions>Options for exporting from MySQL.
schema_only: Option<bool>Export only schemas.
tables: Option<Vec<String>>Tables to export, or that were exported, from the specified database. If you specify tables, specify one and only one database. For PostgreSQL instances, you can specify only one table.