Struct google_sql1_beta4::api::ImportContext [−][src]
pub struct ImportContext {
pub bak_import_options: Option<ImportContextBakImportOptions>,
pub csv_import_options: Option<ImportContextCsvImportOptions>,
pub database: Option<String>,
pub file_type: Option<String>,
pub import_user: Option<String>,
pub kind: Option<String>,
pub uri: Option<String>,
}Expand description
Database instance import context.
This type is not used in any activity, and only used as part of another schema.
Fields
bak_import_options: Option<ImportContextBakImportOptions>Import parameters specific to SQL Server .BAK files
csv_import_options: Option<ImportContextCsvImportOptions>Options for importing data as CSV.
database: Option<String>The target database for the import. If fileType is
SQL, this field is required only if the import file does not
specify a database, and is overridden by any database specification in the
import file. If fileType is CSV, one database
must be specified.
file_type: Option<String>The file type for the specified uri. SQL: The file
contains SQL statements. CSV: The file contains CSV data.
import_user: Option<String>The PostgreSQL user for this import operation. PostgreSQL instances only.
kind: Option<String>This is always sql#importContext.
uri: Option<String>Path to the import file in Cloud Storage, in the form
gs:
//bucketName/fileName. Compressed gzip files (.gz) are supported
// when fileType is SQL. The instance must have
// write permissions to the bucket and read access to the file.