Struct google_sql1_beta4::api::ImportContextBakImportOptionsEncryptionOptions [−][src]
pub struct ImportContextBakImportOptionsEncryptionOptions {
pub cert_path: Option<String>,
pub pvk_password: Option<String>,
pub pvk_path: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
cert_path: Option<String>Path to the Certificate (.cer) in Cloud Storage, in the form
gs://bucketName/fileName. The instance must have
write permissions to the bucket and read access to the file.
pvk_password: Option<String>Password that encrypts the private key
pvk_path: Option<String>Path to the Certificate Private Key (.pvk) in Cloud Storage, in the
form gs://bucketName/fileName. The instance must have
write permissions to the bucket and read access to the file.