Struct google_sql1_beta4::api::ImportContextCsvImportOptions [−][src]
pub struct ImportContextCsvImportOptions {
pub columns: Option<Vec<String>>,
pub table: Option<String>,
}Expand description
Options for importing data as CSV.
This type is not used in any activity, and only used as part of another schema.
Fields
columns: Option<Vec<String>>The columns to which CSV data is imported. If not specified, all columns of the database table are loaded with CSV data.
table: Option<String>The table to which CSV data is imported.