Struct google_sql1_beta4::api::InstancesDemoteMasterRequest [−][src]
pub struct InstancesDemoteMasterRequest {
pub demote_master_context: Option<DemoteMasterContext>,
}Expand description
Database demote master request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- demote master instances (request)
Fields
demote_master_context: Option<DemoteMasterContext>Contains details about the demoteMaster operation.