Struct google_sql1_beta4::api::InstancesExportRequest [−][src]
pub struct InstancesExportRequest {
pub export_context: Option<ExportContext>,
}Expand description
Database instance export request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- export instances (request)
Fields
export_context: Option<ExportContext>Contains details about the export operation.