Struct google_sql1_beta4::api::InstancesListResponse [−][src]
pub struct InstancesListResponse {
pub items: Option<Vec<DatabaseInstance>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub warnings: Option<Vec<ApiWarning>>,
}Expand description
Database instances list response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list instances (response)
Fields
items: Option<Vec<DatabaseInstance>>List of database instance resources.
kind: Option<String>This is always sql#instancesList.
next_page_token: Option<String>The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results.
warnings: Option<Vec<ApiWarning>>List of warnings that occurred while handling the request.