Struct google_sql1_beta4::api::InstancesListServerCasResponse [−][src]
pub struct InstancesListServerCasResponse {
pub active_version: Option<String>,
pub certs: Option<Vec<SslCert>>,
pub kind: Option<String>,
}Expand description
Instances ListServerCas response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list server cas instances (response)
Fields
active_version: Option<String>no description provided
certs: Option<Vec<SslCert>>List of server CA certificates for the instance.
kind: Option<String>This is always sql#instancesListServerCas.