Struct google_sql1_beta4::api::InstancesRotateServerCaRequest [−][src]
pub struct InstancesRotateServerCaRequest {
pub rotate_server_ca_context: Option<RotateServerCaContext>,
}Expand description
Rotate Server CA request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- rotate server ca instances (request)
Fields
rotate_server_ca_context: Option<RotateServerCaContext>Contains details about the rotate server CA operation.