Struct google_sql1_beta4::api::InstancesTruncateLogRequest [−][src]
pub struct InstancesTruncateLogRequest {
pub truncate_log_context: Option<TruncateLogContext>,
}Expand description
Instance truncate log request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- truncate log instances (request)
Fields
truncate_log_context: Option<TruncateLogContext>Contains details about the truncate log operation.