Struct google_sql1_beta4::api::IpConfiguration [−][src]
pub struct IpConfiguration {
pub authorized_networks: Option<Vec<AclEntry>>,
pub ipv4_enabled: Option<bool>,
pub private_network: Option<String>,
pub require_ssl: Option<bool>,
}Expand description
IP Management configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
The list of external networks that are allowed to connect to the instance
using the IP. In CIDR
notation, also known as ‘slash’ notation (e.g.
192.168.100.0/24).
ipv4_enabled: Option<bool>Whether the instance should be assigned an IP address or not.
private_network: Option<String>The resource link for the VPC network from which the Cloud SQL instance is
accessible for private IP. For example,
/projects/myProject/global/networks/default. This setting can
be updated, but it cannot be removed after it is set.
require_ssl: Option<bool>Whether SSL connections over IP should be enforced or not.