Struct google_sql1_beta4::api::IpMapping [−][src]
pub struct IpMapping {
pub ip_address: Option<String>,
pub time_to_retire: Option<String>,
pub type_: Option<String>,
}Expand description
Database instance IP Mapping.
This type is not used in any activity, and only used as part of another schema.
Fields
ip_address: Option<String>The IP address assigned.
time_to_retire: Option<String>The due time for this IP to be retired in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. This field is only available when
the IP is scheduled to be retired.
type_: Option<String>The type of this IP address. A PRIMARY address is a public
address that can accept incoming connections. A PRIVATE
address is a private address that can accept incoming connections. An
OUTGOING address is the source address of connections
originating from the instance, if supported.