Struct google_sql1_beta4::api::LocationPreference [−][src]
pub struct LocationPreference {
pub follow_gae_application: Option<String>,
pub kind: Option<String>,
pub zone: Option<String>,
}Expand description
Preferred location. This specifies where a Cloud SQL instance should preferably be located, either in a specific Compute Engine zone, or co-located with an App Engine application. Note that if the preferred location is not available, the instance will be located as close as possible within the region. Only one location may be specified.
This type is not used in any activity, and only used as part of another schema.
Fields
follow_gae_application: Option<String>The AppEngine application to follow, it must be in the same region as the Cloud SQL instance.
kind: Option<String>This is always sql#locationPreference.
zone: Option<String>The preferred Compute Engine zone (e.g. us-central1-a, us-central1-b, etc.).