Struct google_sql1_beta4::api::MaintenanceWindow [−][src]
pub struct MaintenanceWindow {
pub day: Option<i32>,
pub hour: Option<i32>,
pub kind: Option<String>,
pub update_track: Option<String>,
}Expand description
Maintenance window. This specifies when a v2 Cloud SQL instance should preferably be restarted for system maintenance purposes.
This type is not used in any activity, and only used as part of another schema.
Fields
day: Option<i32>day of week (1-7), starting on Monday.
hour: Option<i32>hour of day - 0 to 23.
kind: Option<String>This is always sql#maintenanceWindow.
update_track: Option<String>Maintenance timing setting: canary (Earlier) or
stable (Later).
Learn more.