Struct google_sql1_beta4::api::MySqlReplicaConfiguration [−][src]
pub struct MySqlReplicaConfiguration {
pub ca_certificate: Option<String>,
pub client_certificate: Option<String>,
pub client_key: Option<String>,
pub connect_retry_interval: Option<i32>,
pub dump_file_path: Option<String>,
pub kind: Option<String>,
pub master_heartbeat_period: Option<String>,
pub password: Option<String>,
pub ssl_cipher: Option<String>,
pub username: Option<String>,
pub verify_server_certificate: Option<bool>,
}Expand description
Read-replica configuration specific to MySQL databases.
This type is not used in any activity, and only used as part of another schema.
Fields
ca_certificate: Option<String>PEM representation of the trusted CA’s x509 certificate.
client_certificate: Option<String>PEM representation of the slave’s x509 certificate.
client_key: Option<String>PEM representation of the slave’s private key. The corresponsing public key is encoded in the client’s certificate.
connect_retry_interval: Option<i32>Seconds to wait between connect retries. MySQL’s default is 60 seconds.
dump_file_path: Option<String>Path to a SQL dump file in Google Cloud Storage from which the slave instance is to be created. The URI is in the form gs: //bucketName/fileName. Compressed gzip files (.gz) are also supported. // Dumps should have the binlog co-ordinates from which replication should // begin. This can be accomplished by setting –master-data to 1 when using // mysqldump.
kind: Option<String>This is always sql#mysqlReplicaConfiguration.
master_heartbeat_period: Option<String>Interval in milliseconds between replication heartbeats.
password: Option<String>The password for the replication connection.
ssl_cipher: Option<String>A list of permissible ciphers to use for SSL encryption.
username: Option<String>The username for the replication connection.
verify_server_certificate: Option<bool>Whether or not to check the master’s Common Name value in the certificate that it sends during the SSL handshake.