Struct google_sql1_beta4::api::OperationErrors [−][src]
pub struct OperationErrors {
pub errors: Option<Vec<OperationError>>,
pub kind: Option<String>,
}Expand description
Database instance operation errors list wrapper.
This type is not used in any activity, and only used as part of another schema.
Fields
errors: Option<Vec<OperationError>>The list of errors encountered while processing this operation.
kind: Option<String>This is always sql#operationErrors.