Struct google_sql1_beta4::api::ProjectMethods [−][src]
pub struct ProjectMethods<'a> { /* fields omitted */ }Expand description
A builder providing access to all methods supported on project resources.
It is not used directly, but through the SQLAdmin hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_sql1_beta4 as sql1_beta4;
use std::default::Default;
use oauth2;
use sql1_beta4::SQLAdmin;
let secret: oauth2::ApplicationSecret = Default::default();
let auth = yup_oauth2::InstalledFlowAuthenticator::builder(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = SQLAdmin::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `instances_reschedule_maintenance(...)`, `instances_start_external_sync(...)` and `instances_verify_external_sync_settings(...)`
// to build up your call.
let rb = hub.projects();Implementations
pub fn instances_reschedule_maintenance(
&self,
request: SqlInstancesRescheduleMaintenanceRequestBody,
project: &str,
instance: &str
) -> ProjectInstanceRescheduleMaintenanceCall<'a>
pub fn instances_reschedule_maintenance(
&self,
request: SqlInstancesRescheduleMaintenanceRequestBody,
project: &str,
instance: &str
) -> ProjectInstanceRescheduleMaintenanceCall<'a>
Create a builder to help you perform the following task:
Reschedules the maintenance on the given instance.
Arguments
request- No description provided.project- ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.
pub fn instances_start_external_sync(
&self,
project: &str,
instance: &str
) -> ProjectInstanceStartExternalSyncCall<'a>
pub fn instances_start_external_sync(
&self,
project: &str,
instance: &str
) -> ProjectInstanceStartExternalSyncCall<'a>
Create a builder to help you perform the following task:
Start External master migration.
Arguments
project- ID of the project that contains the first generation instance.instance- Cloud SQL instance ID. This does not include the project ID.
pub fn instances_verify_external_sync_settings(
&self,
project: &str,
instance: &str
) -> ProjectInstanceVerifyExternalSyncSettingCall<'a>
pub fn instances_verify_external_sync_settings(
&self,
project: &str,
instance: &str
) -> ProjectInstanceVerifyExternalSyncSettingCall<'a>
Create a builder to help you perform the following task:
Verify External master external sync settings.
Arguments
project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.