Struct google_sql1_beta4::api::Reschedule [−][src]
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
reschedule_type: Option<String>Required. The type of the reschedule.
schedule_time: Option<String>Optional. Timestamp when the maintenance shall be rescheduled to if
reschedule_type=SPECIFIC_TIME, in RFC 3339 format, for
example 2012-11-15T16:19:00.094Z.