Struct google_sql1_beta4::api::RestoreBackupContext [−][src]
pub struct RestoreBackupContext {
pub backup_run_id: Option<String>,
pub instance_id: Option<String>,
pub kind: Option<String>,
pub project: Option<String>,
}Expand description
Database instance restore from backup context. Backup context contains source instance id and project id.
This type is not used in any activity, and only used as part of another schema.
Fields
backup_run_id: Option<String>The ID of the backup run to restore from.
instance_id: Option<String>The ID of the instance that the backup was taken from.
kind: Option<String>This is always sql#restoreBackupContext.
project: Option<String>The full project ID of the source instance.