Struct google_sql1_beta4::api::RotateServerCaContext [−][src]
Instance rotate server CA context.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>This is always sql#rotateServerCaContext.
next_version: Option<String>The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server CA version.