Struct google_sql1_beta4::api::SqlInstancesRescheduleMaintenanceRequestBody [−][src]
pub struct SqlInstancesRescheduleMaintenanceRequestBody {
pub reschedule: Option<Reschedule>,
}Expand description
Reschedule options for maintenance windows.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
reschedule: Option<Reschedule>Required. The type of the reschedule the user wants.