Struct google_sql1_beta4::api::SqlScheduledMaintenance [−][src]
pub struct SqlScheduledMaintenance {
pub can_defer: Option<bool>,
pub can_reschedule: Option<bool>,
pub start_time: Option<String>,
}Expand description
Any scheduled maintenancce for this instance.
This type is not used in any activity, and only used as part of another schema.
Fields
can_defer: Option<bool>no description provided
can_reschedule: Option<bool>If the scheduled maintenance can be rescheduled.
start_time: Option<String>The start time of any upcoming scheduled maintenance for this instance.