Struct google_sql1_beta4::api::SqlServerDatabaseDetails [−][src]
pub struct SqlServerDatabaseDetails {
pub compatibility_level: Option<i32>,
pub recovery_model: Option<String>,
}Expand description
Represents a Sql Server database on the Cloud SQL instance.
This type is not used in any activity, and only used as part of another schema.
Fields
compatibility_level: Option<i32>The version of SQL Server with which the database is to be made compatible
recovery_model: Option<String>The recovery model of a SQL Server database