Struct google_sql1_beta4::api::SqlServerUserDetails [−][src]
pub struct SqlServerUserDetails {
pub disabled: Option<bool>,
pub server_roles: Option<Vec<String>>,
}Expand description
Represents a Sql Server user on the Cloud SQL instance.
This type is not used in any activity, and only used as part of another schema.
Fields
disabled: Option<bool>If the user has been disabled
server_roles: Option<Vec<String>>The server roles for this user