Struct google_sql1_beta4::api::SslCertDetail [−][src]
SslCertDetail.
This type is not used in any activity, and only used as part of another schema.
Fields
cert_info: Option<SslCert>The public information about the cert.
cert_private_key: Option<String>The private key for the client cert, in pem format. Keep private in order to protect your security.