Struct google_sql1_beta4::api::SslCertMethods [−][src]
pub struct SslCertMethods<'a> { /* fields omitted */ }Expand description
A builder providing access to all methods supported on sslCert resources.
It is not used directly, but through the SQLAdmin hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_sql1_beta4 as sql1_beta4;
use std::default::Default;
use oauth2;
use sql1_beta4::SQLAdmin;
let secret: oauth2::ApplicationSecret = Default::default();
let auth = yup_oauth2::InstalledFlowAuthenticator::builder(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = SQLAdmin::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `create_ephemeral(...)`, `delete(...)`, `get(...)`, `insert(...)` and `list(...)`
// to build up your call.
let rb = hub.ssl_certs();Implementations
pub fn create_ephemeral(
&self,
request: SslCertsCreateEphemeralRequest,
project: &str,
instance: &str
) -> SslCertCreateEphemeralCall<'a>
pub fn create_ephemeral(
&self,
request: SslCertsCreateEphemeralRequest,
project: &str,
instance: &str
) -> SslCertCreateEphemeralCall<'a>
Create a builder to help you perform the following task:
Generates a short-lived X509 certificate containing the provided public key and signed by a private key specific to the target instance. Users may use the certificate to authenticate as themselves when connecting to the database.
Arguments
request- No description provided.project- Project ID of the Cloud SQL project.instance- Cloud SQL instance ID. This does not include the project ID.
Create a builder to help you perform the following task:
Deletes the SSL certificate. For First Generation instances, the certificate remains valid until the instance is restarted.
Arguments
project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.sha1Fingerprint- Sha1 FingerPrint.
Create a builder to help you perform the following task:
Retrieves a particular SSL certificate. Does not include the private key (required for usage). The private key must be saved from the response to initial creation.
Arguments
project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.sha1Fingerprint- Sha1 FingerPrint.
pub fn insert(
&self,
request: SslCertsInsertRequest,
project: &str,
instance: &str
) -> SslCertInsertCall<'a>
pub fn insert(
&self,
request: SslCertsInsertRequest,
project: &str,
instance: &str
) -> SslCertInsertCall<'a>
Create a builder to help you perform the following task:
Creates an SSL certificate and returns it along with the private key and server certificate authority. The new certificate will not be usable until the instance is restarted.
Arguments
request- No description provided.project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.
Create a builder to help you perform the following task:
Lists all of the current SSL certificates for the instance.
Arguments
project- Project ID of the project that contains the instance.instance- Cloud SQL instance ID. This does not include the project ID.