Struct google_sql1_beta4::api::SslCertsInsertResponse [−][src]
pub struct SslCertsInsertResponse {
pub client_cert: Option<SslCertDetail>,
pub kind: Option<String>,
pub operation: Option<Operation>,
pub server_ca_cert: Option<SslCert>,
}Expand description
SslCert insert response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- insert ssl certs (response)
Fields
client_cert: Option<SslCertDetail>The new client certificate and private key. For First Generation instances, the new certificate does not take effect until the instance is restarted.
kind: Option<String>This is always sql#sslCertsInsert.
operation: Option<Operation>The operation to track the ssl certs insert request.
server_ca_cert: Option<SslCert>The server Certificate Authority’s certificate. If this is missing you can force a new one to be generated by calling resetSslConfig method on instances resource.