Struct google_sql1_beta4::api::Tier [−][src]
pub struct Tier {
pub disk_quota: Option<String>,
pub ram: Option<String>,
pub kind: Option<String>,
pub region: Option<Vec<String>>,
pub tier: Option<String>,
}Expand description
A Google Cloud SQL service tier resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list tiers (none)
Fields
disk_quota: Option<String>The maximum disk size of this tier in bytes.
ram: Option<String>The maximum RAM usage of this tier in bytes.
kind: Option<String>This is always sql#tier.
region: Option<Vec<String>>The applicable regions for this tier.
tier: Option<String>An identifier for the machine type, for example, db-n1-standard-1. For related information, see Pricing.