Struct google_sql1_beta4::api::TiersListResponse [−][src]
Tiers list response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list tiers (response)
Fields
items: Option<Vec<Tier>>List of tiers.
kind: Option<String>This is always sql#tiersList.