Struct google_sql1_beta4::api::UserMethods [−][src]
pub struct UserMethods<'a> { /* fields omitted */ }Expand description
A builder providing access to all methods supported on user resources.
It is not used directly, but through the SQLAdmin hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_sql1_beta4 as sql1_beta4;
use std::default::Default;
use oauth2;
use sql1_beta4::SQLAdmin;
let secret: oauth2::ApplicationSecret = Default::default();
let auth = yup_oauth2::InstalledFlowAuthenticator::builder(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = SQLAdmin::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `insert(...)`, `list(...)` and `update(...)`
// to build up your call.
let rb = hub.users();Implementations
Create a builder to help you perform the following task:
Deletes a user from a Cloud SQL instance.
Arguments
project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.
Create a builder to help you perform the following task:
Creates a new user in a Cloud SQL instance.
Arguments
request- No description provided.project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.
Create a builder to help you perform the following task:
Lists users in the specified Cloud SQL instance.
Arguments
project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.
Create a builder to help you perform the following task:
Updates an existing user in a Cloud SQL instance.
Arguments
request- No description provided.project- Project ID of the project that contains the instance.instance- Database instance ID. This does not include the project ID.