Struct google_sql1_beta4::api::UsersListResponse [−][src]
pub struct UsersListResponse {
pub items: Option<Vec<User>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
User list response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list users (response)
Fields
items: Option<Vec<User>>List of user resources in the instance.
kind: Option<String>This is always sql#usersList.
next_page_token: Option<String>An identifier that uniquely identifies the operation. You can use this identifier to retrieve the Operations resource that has information about the operation.